@@ -62,6 +62,12 @@ ug <- function(..., result="graphNEL"){
   ugList(list(...), result=result)
 }
 
+#' @export
+#' @rdname graph-create
+ugi <- function(...){
+  ugList(list(...), result="igraph")
+}
+
 .spam.result <- function(result){
     ##if (identical(result, "Matrix")) stop('"Matrix" is deprecated; use "dgCMatrix" instead\n')
     if (identical(result, "NEL")) stop('"NEL" is deprecated; use "graphNEL" instead\n')
@@ -95,6 +101,12 @@ dag <- function(..., result="graphNEL", forceCheck=FALSE){
   dagList(list(...), result=result, forceCheck=forceCheck)
 }
 
+#' @export
+#' @rdname graph-create
+dagi <- function(..., forceCheck=FALSE){
+  dagList(list(...), result="igraph", forceCheck=forceCheck)
+}
+
 #' @export
 #' @rdname graph-create
 dagList <- function(x, result="graphNEL", forceCheck=FALSE){
